/*
** Module   : Viewport.java
** Abstract : View port for widget. It allows to see only a part of the 
**            widget visible through "window" - view port.
**
** Copyright (c) 2010, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --JPRM-- ----------------Description-----------------
** 001 SIY 20100629          Created initial version
** 002 SIY 20100804          Changes in imports, some refactorings.
** 003 SIY 20101122          setExtent() not is public.
*/

package com.goldencode.p2j.ui.client.widget;

import com.goldencode.p2j.ui.client.*;

/**
 * Viewport container.
 */
public class Viewport
extends AbstractContainer
{
   /** Viewport dimensions. */
   private Dimension extent;

   /** Widget which is visible through this viewport. */
   private Widget view;

   /**
    * Constructor.
    * 
    * @param   view
    *          Widget which will be visible through viewport.          
    */
   public Viewport(Widget view)
   {
      this.view = view;
      add(view);
      addToTabOrder(view, 0);
   }

   /**
    * Get widget bounding rectangle.
    * 
    * @return  bounding rectangle.
    */
   @Override
   public Rectangle bounds()
   {
      return new Rectangle(location(), extent());
   }

   /**
    * Draw widget.
    */
   @Override
   public void draw()
   {
      Point origin = screenLocation();
      Rectangle rect = new Rectangle(origin, extent());

      ScreenBitmap bitmap = screen().getAndSetBitmap(rect);
      view.draw();
      screen().setBitmap(bitmap);
   }

   /**
    * Size of visible part of viewport.
    *  
    * @return visible part size.  
    */
   public Dimension extent()
   {
      return extent.copy();
   }

   /**
    * Get underlying widget.
    * 
    * @return  underlying widget.
    */
   public Widget view()
   {
      return view;
   }

   /**
    * Set visible part size.
    * 
    * @param   width
    *          Extent width.
    * @param   height
    *          Extent height.
    */
   public void setExtent(int width, int height)
   {
      extent = new Dimension(width, height);
   }
}
